@@ -1,10 +1,8 @@
 import copy
 from pathlib import Path
 
-from brain_brew.representation.configuration.global_config import GlobalConfig
 
-
-class SourceFile:
+class SourceFile(object):
     @classmethod
     def from_file_loc(cls, file_loc) -> 'SourceFile':
         pass
@@ -23,7 +21,7 @@ class SourceFile:
 
     @classmethod
     def create_or_get(cls, location):
-        from brain_brew.file_manager import FileManager
+        from brain_brew.configuration.file_manager import FileManager
         _file_manager = FileManager.get_instance()
         formatted_location = cls.formatted_file_location(location)
         file = _file_manager.file_if_exists(formatted_location)
@@ -31,6 +29,9 @@ class SourceFile:
         if file is not None:
             return file
 
+        # if not cls.is_file(location) and not cls.is_dir(location):
+        #     raise FileNotFoundError(f"No file or folder '{location}' exists")
+
         file = cls.from_file_loc(location)
         _file_manager.register_file(formatted_location, file)
         return file
