@@ -3,7 +3,7 @@ import sys
 
 sys.path.append(os.path.abspath(''))
 
-from brain_brew.configuration.build_config.top_level_builder import TopLevelBuilder
+from brain_brew.commands.run_recipe.top_level_builder import TopLevelBuilder
 
 build: str = TopLevelBuilder.build_yamale()
 filepath = "brain_brew/schemas/recipe.yaml"
